@@ -1,5 +1,5 @@
-require 'minitest/unit'
-require 'minitest/spec'
+require "minitest/test"
+require "minitest/spec"
 
 module Minitest
   ##
@@ -18,8 +18,7 @@ module Minitest
     end
 
     def self.run reporter, options = {} # :nodoc:
-      # NOTE: this is truly horrible... but I don't see a way around this ATM.
-      @io = reporter.reporters.first.io
+      @io = reporter.io
       super
     end
 
@@ -48,8 +47,6 @@ module Minitest
 
     def self.bench_linear min, max, step = 10
       (min..max).step(step).to_a
-    rescue LocalJumpError # 1.8.6
-      r = []; (min..max).step(step) { |n| r << n }; r
     end
 
     ##
@@ -84,15 +81,15 @@ module Minitest
     def assert_performance validation, &work
       range = self.class.bench_range
 
-      io.print "#{self.name}"
+      io.print self.name
 
       times = []
 
       range.each do |x|
         GC.start
-        t0 = Time.now
+        t0 = Minitest.clock_time
         instance_exec(x, &work)
-        t = Time.now - t0
+        t = Minitest.clock_time - t0
 
         io.print "\t%9.6f" % t
         times << t
@@ -110,8 +107,8 @@ module Minitest
     # is applied against the slope itself. As such, you probably want
     # to tighten it from the default.
     #
-    # See http://www.graphpad.com/curvefit/goodness_of_fit.htm for
-    # more details.
+    # See https://www.graphpad.com/guides/prism/8/curve-fitting/reg_intepretingnonlinr2.htm
+    # for more details.
     #
     # Fit is calculated by #fit_linear.
     #
@@ -218,11 +215,11 @@ module Minitest
     ##
     # Takes an array of x/y pairs and calculates the general R^2 value.
     #
-    # See: http://en.wikipedia.org/wiki/Coefficient_of_determination
+    # See: https://en.wikipedia.org/wiki/Coefficient_of_determination
 
     def fit_error xys
-      y_bar  = sigma(xys) { |x, y| y } / xys.size.to_f
-      ss_tot = sigma(xys) { |x, y| (y    - y_bar) ** 2 }
+      y_bar  = sigma(xys) { |_, y| y } / xys.size.to_f
+      ss_tot = sigma(xys) { |_, y| (y    - y_bar) ** 2 }
       ss_err = sigma(xys) { |x, y| (yield(x) - y) ** 2 }
 
       1 - (ss_err / ss_tot)
@@ -233,14 +230,14 @@ module Minitest
     #
     # Takes x and y values and returns [a, b, r^2].
     #
-    # See: http://mathworld.wolfram.com/LeastSquaresFittingExponential.html
+    # See: https://mathworld.wolfram.com/LeastSquaresFittingExponential.html
 
     def fit_exponential xs, ys
       n     = xs.size
-      xys   = xs.zip(ys)
-      sxlny = sigma(xys) { |x,y| x * Math.log(y) }
-      slny  = sigma(xys) { |x,y| Math.log(y)     }
-      sx2   = sigma(xys) { |x,y| x * x           }
+      xys   = xs.zip ys
+      sxlny = sigma(xys) { |x, y| x * Math.log(y) }
+      slny  = sigma(xys) { |_, y| Math.log(y)     }
+      sx2   = sigma(xys) { |x, _| x * x           }
       sx    = sigma xs
 
       c = n * sx2 - sx ** 2
@@ -255,15 +252,15 @@ module Minitest
     #
     # Takes x and y values and returns [a, b, r^2].
     #
-    # See: http://mathworld.wolfram.com/LeastSquaresFittingLogarithmic.html
+    # See: https://mathworld.wolfram.com/LeastSquaresFittingLogarithmic.html
 
     def fit_logarithmic xs, ys
       n     = xs.size
-      xys   = xs.zip(ys)
-      slnx2 = sigma(xys) { |x,y| Math.log(x) ** 2 }
-      slnx  = sigma(xys) { |x,y| Math.log(x)      }
-      sylnx = sigma(xys) { |x,y| y * Math.log(x)  }
-      sy    = sigma(xys) { |x,y| y                }
+      xys   = xs.zip ys
+      slnx2 = sigma(xys) { |x, _| Math.log(x) ** 2 }
+      slnx  = sigma(xys) { |x, _| Math.log(x)      }
+      sylnx = sigma(xys) { |x, y| y * Math.log(x)  }
+      sy    = sigma(xys) { |_, y| y                }
 
       c = n * slnx2 - slnx ** 2
       b = ( n * sylnx - sy * slnx ) / c
@@ -272,21 +269,20 @@ module Minitest
       return a, b, fit_error(xys) { |x| a + b * Math.log(x) }
     end
 
-
     ##
     # Fits the functional form: a + bx.
     #
     # Takes x and y values and returns [a, b, r^2].
     #
-    # See: http://mathworld.wolfram.com/LeastSquaresFitting.html
+    # See: https://mathworld.wolfram.com/LeastSquaresFitting.html
 
     def fit_linear xs, ys
       n   = xs.size
-      xys = xs.zip(ys)
+      xys = xs.zip ys
       sx  = sigma xs
       sy  = sigma ys
       sx2 = sigma(xs)  { |x|   x ** 2 }
-      sxy = sigma(xys) { |x,y| x * y  }
+      sxy = sigma(xys) { |x, y| x * y  }
 
       c = n * sx2 - sx**2
       a = (sy * sx2 - sx * sxy) / c
@@ -300,17 +296,17 @@ module Minitest
     #
     # Takes x and y values and returns [a, b, r^2].
     #
-    # See: http://mathworld.wolfram.com/LeastSquaresFittingPowerLaw.html
+    # See: https://mathworld.wolfram.com/LeastSquaresFittingPowerLaw.html
 
     def fit_power xs, ys
       n       = xs.size
-      xys     = xs.zip(ys)
+      xys     = xs.zip ys
       slnxlny = sigma(xys) { |x, y| Math.log(x) * Math.log(y) }
       slnx    = sigma(xs)  { |x   | Math.log(x)               }
       slny    = sigma(ys)  { |   y| Math.log(y)               }
       slnx2   = sigma(xs)  { |x   | Math.log(x) ** 2          }
 
-      b = (n * slnxlny - slnx * slny) / (n * slnx2 - slnx ** 2);
+      b = (n * slnxlny - slnx * slny) / (n * slnx2 - slnx ** 2)
       a = (slny - b * slnx) / n
 
       return Math.exp(a), b, fit_error(xys) { |x| (Math.exp(a) * (x ** b)) }
@@ -320,12 +316,12 @@ module Minitest
     # Enumerates over +enum+ mapping +block+ if given, returning the
     # sum of the result. Eg:
     #
-    #   sigma([1, 2, 3])                # => 1 + 2 + 3 => 7
+    #   sigma([1, 2, 3])                # => 1 + 2 + 3 => 6
     #   sigma([1, 2, 3]) { |n| n ** 2 } # => 1 + 4 + 9 => 14
 
     def sigma enum, &block
       enum = enum.map(&block) if block
-      enum.inject { |sum, n| sum + n }
+      enum.sum
     end
 
     ##
@@ -343,6 +339,9 @@ module Minitest
 end
 
 module Minitest
+  ##
+  # The spec version of Minitest::Benchmark.
+
   class BenchSpec < Benchmark
     extend Minitest::Spec::DSL
 
@@ -354,7 +353,7 @@ module Minitest
     # See ::bench_performance_linear for an example of how to use this.
 
     def self.bench name, &block
-      define_method "bench_#{name.gsub(/\W+/, '_')}", &block
+      define_method "bench_#{name.gsub(/\W+/, "_")}", &block
     end
 
     ##
@@ -376,7 +375,7 @@ module Minitest
     ##
     # Create a benchmark that verifies that the performance is linear.
     #
-    #   describe "my class" do
+    #   describe "my class Bench" do
     #     bench_performance_linear "fast_algorithm", 0.9999 do |n|
     #       @obj.fast_algorithm(n)
     #     end
@@ -391,7 +390,7 @@ module Minitest
     ##
     # Create a benchmark that verifies that the performance is constant.
     #
-    #   describe "my class" do
+    #   describe "my class Bench" do
     #     bench_performance_constant "zoom_algorithm!" do |n|
     #       @obj.zoom_algorithm!(n)
     #     end
@@ -406,7 +405,7 @@ module Minitest
     ##
     # Create a benchmark that verifies that the performance is exponential.
     #
-    #   describe "my class" do
+    #   describe "my class Bench" do
     #     bench_performance_exponential "algorithm" do |n|
     #       @obj.algorithm(n)
     #     end
@@ -417,6 +416,36 @@ module Minitest
         assert_performance_exponential threshold, &work
       end
     end
+
+    ##
+    # Create a benchmark that verifies that the performance is logarithmic.
+    #
+    #   describe "my class Bench" do
+    #     bench_performance_logarithmic "algorithm" do |n|
+    #       @obj.algorithm(n)
+    #     end
+    #   end
+
+    def self.bench_performance_logarithmic name, threshold = 0.99, &work
+      bench name do
+        assert_performance_logarithmic threshold, &work
+      end
+    end
+
+    ##
+    # Create a benchmark that verifies that the performance is power.
+    #
+    #   describe "my class Bench" do
+    #     bench_performance_power "algorithm" do |n|
+    #       @obj.algorithm(n)
+    #     end
+    #   end
+
+    def self.bench_performance_power name, threshold = 0.99, &work
+      bench name do
+        assert_performance_power threshold, &work
+      end
+    end
   end
 
   Minitest::Spec.register_spec_type(/Bench(mark)?$/, Minitest::BenchSpec)
